@@ -1,18 +1,18 @@
 package Syntax::Feature::Maybe;
 
-use 5.008;
+use 5.006;
 use strict;
 use PerlX::Maybe qw//;
 
 BEGIN {
 	$Syntax::Feature::Maybe::AUTHORITY = 'cpan:TOBYINK';
-	$Syntax::Feature::Maybe::VERSION   = '0.003';
+	$Syntax::Feature::Maybe::VERSION   = '1.000';
 }
 
 sub install
-{	
+{
 	my ($class, %args) = @_;
-	my $into = delete $args{into};
+	my $into = delete($args{into});
 	
 	foreach my $f (qw/maybe/)
 	{
@@ -24,6 +24,10 @@ sub install
 __FILE__
 __END__
 
+=pod
+
+=encoding utf8
+
 =head1 NAME
 
 Syntax::Feature::Maybe - use syntax qw/maybe/
